@@ -15,12 +15,14 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Authors: Glynn Foster <glynn.foster@sun.com>
  */
 
+#include "config.h"
+
 #include <glade/glade.h>
 #include "zenity.h"
 #include "util.h"
@@ -110,6 +112,9 @@ zenity_msg (ZenityData *data, ZenityMsgData *msg_data)
   if (msg_data->dialog_text)
     gtk_label_set_markup (GTK_LABEL (text), msg_data->dialog_text);
 
+  if (msg_data->no_wrap)
+    gtk_label_set_line_wrap (GTK_LABEL (text), FALSE);
+
   zenity_util_show_dialog (dialog);
   gtk_main ();
 }
